# The Official Anger Package
### The best way for programmamamaers to raeg over br0ken cod3

# LISTEN THERE IS ONLY ONE FUNCTION.  IF YOU DON'T SPECIFY A RAGE AMOUNT, THE RAGE IT GIVES IS VERY LAME.

#### Example:
`$ pip install angerr`
```
from anger import anger

anger(5)
```
#### Output

1. WHY IS CODING SO HARD
2. WHY IS CODING SO HARD
3. WHY IS CODING SO HARD
4. WHY IS CODING SO HARD
5. WHY IS CODING SO HARD

finally done raging.  are you?


# REEEEEEEEEEEEEEEEEEEEEEEeE